@@ -2,7 +2,7 @@
 {
 	if (missing(model))
 		stop("model is missing");
-	if (class(model) != "variogram.model")
+	if (!inherits(model, "variogram.model"))
 		stop("model should be of mode variogram.model (use function vgm)")
 	anis = c(model$ang1, model$ang2, model$ang3, model$anis1, model$anis2)
 	.C("Cgstat_load_variogram", 
